/*
   Flying Toasters in 32x32 RGB LED matrix
   scruss - 2017-07 - for elmwood.to
   freely modified from
   - Phillip Burgess's Animated Flying Toasters for Adafruit
   - Adafruit RGB matrix examples by Limor Fried and Phillip Burgess
   The toaster bitmaps are most likely lifted from Berkeley Systems'
   "After Dark" screen saver for the Apple Macintosh.
*/
#include <Adafruit_GFX.h>   // Core graphics library
#include <RGBmatrixPanel.h> // Hardware-specific library
#include "bitmaps.h"

// Colour definitions - format is RGB-565
#define BLACK    0x0000
#define BLUE     0x001F
#define RED      0xF800
#define GREEN    0x07E0
#define CYAN     0x07FF
#define MAGENTA  0xF81F
#define YELLOW   0xFFE0
#define WHITE    0xFFFF

uint16_t colarray[] = { BLUE, RED, GREEN, CYAN, MAGENTA, YELLOW, WHITE };
#define COLMOD 7
int colsub = 0;

// 32x32 matrix with SINGLE HEADER input pinout
// talking to Nootropic Matrix Backpack v2
#define CLK 8
#define OE  9
#define LAT 10
#define A   A0
#define B   A1
#define C   A2
#define D   A3
// If your matrix has the DOUBLE HEADER input,
//  please use values from RGB matrix panel code examples

RGBmatrixPanel matrix(A, B, C, D, CLK, LAT, OE, false);
int i = 0;

void setup() {
  matrix.begin();
  matrix.fillScreen(BLACK);
}

void loop() {
  // first draw mask in black to clean up stray pixels
  matrix.drawBitmap(0, 0, (const uint8_t *)pgm_read_word(&mask[i]), 32, 32, BLACK);
  // next draw bitmap in the colour we want
  matrix.drawBitmap(0, 0, (const uint8_t *)pgm_read_word(&img[i]), 32, 32, colarray[colsub]);
  i++;
  if (i == 4) {
    // reset frame count as there are only 4 frames
    i = 0;
    // change colour too
    colsub++;
    colsub %= COLMOD;
  }
  delay(75);
}
